@@ -1,5 +1,5 @@
 /*  ADCD - A Diminutive CD player for Linux/GNU
-    Copyright (C) 2004-2017 Antonio Diaz Diaz.
+    Copyright (C) 2004-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,16 +36,23 @@
 
 namespace {
 
-const char * const Program_name = "Adcd";
 const char * const program_name = "adcd";
-const char * const program_year = "2017";
+const char * const program_year = "2019";
 const char * invocation_name = 0;
 
 
 void show_help()
   {
-  std::printf( "%s - A Diminutive CD player for Linux/GNU.\n", Program_name );
-  std::printf( "If invoked without options enters interactive mode.\n"
+  std::printf( "Adcd is a cd player for Linux/GNU with a ncurses (text mode) interface.\n"
+               "\nAdcd can play all the tracks from a disc in order (linear mode), or in the\n"
+               "order specified by the user (playlist mode), and includes all the functions\n"
+               "expected in a stand-alone cd player, including random play and loop mode.\n"
+               "\nAdcd also features a non-interactive mode for those who want to play their\n"
+               "CDs while using the console for something else.\n"
+               "\nMost probably the CD drive needs to be connected to the audio card through\n"
+               "an analog audio cable for adcd to be able to play the CD. You may also need\n"
+               "a mixer program like rexima or aumix to activate the audio card.\n"
+               "\nIf invoked without options, adcd enters interactive mode.\n"
                "\nUsage: %s [options] [device]\n", invocation_name );
   std::printf( "\nOptions:\n"
                "  -h, --help              display this help and exit\n"
@@ -85,9 +92,6 @@ void show_help()
                "  Backspace          Delete track preceding cursor\n"
                "  Enter              Store playlist and exit edit mode\n"
                "  Q                  Discard changes and exit edit mode\n"
-               "\nMost probably the CD drive needs to be connected to the audio card\n"
-               "through an analog audio cable for adcd to be able to play the CD.\n"
-               "You may also need a mixer program like rexima to activate the audio card.\n"
                "\nExit status: 0 for a normal exit, 1 for environmental problems (file\n"
                "not found, invalid flags, I/O errors, etc), 2 to indicate a corrupt or\n"
                "invalid input file, 3 for an internal consistency error (eg, bug) which\n"
@@ -111,11 +115,9 @@ void show_error( const char * const msg, const int errcode = 0,
                  const bool help = false )
   {
   if( msg && msg[0] )
-    {
-    std::fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
-    std::fputc( '\n', stderr );
-    }
+    std::fprintf( stderr, "%s: %s%s%s\n", program_name, msg,
+                  ( errcode > 0 ) ? ": " : "",
+                  ( errcode > 0 ) ? std::strerror( errcode ) : "" );
   if( help )
     std::fprintf( stderr, "Try '%s --help' for more information.\n",
                   invocation_name );
